==> snk-browser-helper-print-0.1.1.tgz: package/src/components/services/HttpService.js <==
/**
 * Created by LynnLin on 2019/05/08.
 */
import HttpUtils from '../utils/HttpUtils';

const host = 'http://127.0.0.1:19877/h/'
// const host = 'http://10.11.32.129:19877/h/'

// HttpUtils.initHttpUtils({ ajaxType: 'ajax' });

export default class Services{
  static async getPrintList() { // 获取初始化信息
    return HttpUtils.get({
      server: host,
      url: '/printList',
      body: null,
    });
  }

  static async doPrint(payload) { // 进行打印
    console.log(payload)
    return HttpUtils.post({
      server: host,
      url: '/hprint',
      body: {
        ...payload,
      },
    });
  }

  static evenloop = function (urls, hander, index, success, errorFn) {
    const seqution = [].concat(urls);
    let indexNum = index;
    const Len = seqution.length;
    try {
      Services.getPrintList().then((data)=> {
        hander(seqution[indexNum]).then(()=> {
          if (indexNum < Len - 1) {
            evenloop(seqution, hander, indexNum + 1, success, errorFn)
          } else {
            if (success) {
              success()
            }
          }
        }).catch((errorData)=> {
          if (errorFn) {
            errorFn(errorData, indexNum);
          }
        });
      }).catch((errorFn)=> {
        if (errorFn) {
          errorFn(errorData, indexNum);
        }
      });

    } catch (errorData) {
      if (errorFn) {
        console.log(errorFn)
        errorFn(errorData, indexNum);
      }
    }
  }

  static limitLoad = function(urls, hander, limit, errorCallBack) {
    const seqution = [].concat(urls);
    let promises = []; // 执行的相关promise数组
    // 首先拿出limit个进行执行
    promises = seqution.splice(0, limit).map((url, index) => {
        return hander(url).then(() => {
            return index; // 输出当前执行的下标
        }).catch((error) => {
          errorCallBack(error);
      })
    })
    let p = Promise.race(promises); // 谁先执行完，谁先出来
    for(let i = 0; i < seqution.length; i += 1) {
        const elmentUrl = seqution[i];
        p = p.then((res) => {
            promises[res] =
            hander(elmentUrl).then(() => {//执行完res下标的promise,继续下一个promise覆盖res下标
                return res;
            }).catch((error) => {
              errorCallBack(error);
          })
            return Promise.race(promises);
        })
    }
  }
};

==> snk-browser-helper-print-0.1.3.tgz: package/src/components/services/HttpService.js <==
/**
 * Created by LynnLin on 2019/05/08.
 */
import HttpUtils from '../utils/HttpUtils';

const host = 'http://127.0.0.1:19877/h/'
// const host = 'http://10.11.32.129:19877/h/'

// HttpUtils.initHttpUtils({ ajaxType: 'ajax' });

export default class Services{
  static async getPrintList() { // 获取初始化信息
    return HttpUtils.get({
      server: host,
      url: '/printList',
      body: null,
    });
  }

  static async doPrint(payload) { // 进行打印
    console.log(payload)
    return HttpUtils.post({
      server: host,
      url: '/hprint',
      body: {
        ...payload,
      },
    });
  }

  static evenloop = function (urls, hander, index, success, errorFn) {
    const seqution = [].concat(urls);
    let indexNum = index;
    const Len = seqution.length;
    try {
      Services.getPrintList().then((data)=> {
        hander(seqution[indexNum]).then(()=> {
          if (indexNum < Len - 1) {
            Services.evenloop(seqution, hander, indexNum + 1, success, errorFn)
          } else {
            if (success) {
              success()
            }
          }
        }).catch((errorData)=> {
          if (errorFn) {
            errorFn(errorData, indexNum);
          }
        });
      }).catch((errorFn)=> {
        if (errorFn) {
          errorFn(errorData, indexNum);
        }
      });

    } catch (errorData) {
      if (errorFn) {
        console.log(errorFn)
        errorFn(errorData, indexNum);
      }
    }
  }

  static limitLoad = function(urls, hander, limit, errorCallBack) {
    const seqution = [].concat(urls);
    let promises = []; // 执行的相关promise数组
    // 首先拿出limit个进行执行
    promises = seqution.splice(0, limit).map((url, index) => {
        return hander(url).then(() => {
            return index; // 输出当前执行的下标
        }).catch((error) => {
          errorCallBack(error);
      })
    })
    let p = Promise.race(promises); // 谁先执行完，谁先出来
    for(let i = 0; i < seqution.length; i += 1) {
        const elmentUrl = seqution[i];
        p = p.then((res) => {
            promises[res] =
            hander(elmentUrl).then(() => {//执行完res下标的promise,继续下一个promise覆盖res下标
                return res;
            }).catch((error) => {
              errorCallBack(error);
          })
            return Promise.race(promises);
        })
    }
  }
};
